@@ -164,10 +164,11 @@ API_AVAILABLE(ios(13.0))
 /*----------------------------------------------------------------------------------------------*/
 
 @interface AppState : NSObject<UIDocumentPickerDelegate, UITextFieldDelegate, UITextViewDelegate,
-                               UIScrollViewDelegate> {
+                               UIScrollViewDelegate, NSLayoutManagerDelegate> {
     iString *fileBeingSaved;
     iString *pickFileCommand;
     iSystemTextInput *sysCtrl;
+    float sysCtrlLineSpacing;
 }
 @property (nonatomic, assign) BOOL isHapticsAvailable;
 @property (nonatomic, strong) NSObject *haptic;
@@ -183,17 +184,10 @@ static UIScrollView *statusBarTapper_; /* dummy scroll view just for getting not
     fileBeingSaved = NULL;
     pickFileCommand = NULL;
     sysCtrl = NULL;
+    sysCtrlLineSpacing = 0.0f;
     return self;
 }
 
--(void)setSystemTextInput:(iSystemTextInput *)sys {
-    sysCtrl = sys;
-}
-
--(iSystemTextInput *)systemTextInput {
-    return sysCtrl;
-}
-
 -(void)setPickFileCommand:(const char *)command {
     if (!pickFileCommand) {
         pickFileCommand = new_String();
@@ -256,6 +250,11 @@ didPickDocumentsAtURLs:(NSArray<NSURL *> *)urls {
     }
 }
 
+- (BOOL)scrollViewShouldScrollToTop:(UIScrollView *)scrollView {
+    postCommand_App("scroll.top smooth:1");
+    return NO;
+}
+
 -(void)keyboardOnScreen:(NSNotification *)notification {
     NSDictionary *info   = notification.userInfo;
     NSValue      *value  = info[UIKeyboardFrameEndUserInfoKey];
@@ -289,6 +288,24 @@ static void sendReturnKeyPress_(void) {
     return NO;
 }
 
+-(void)setSystemTextInput:(iSystemTextInput *)sys {
+    sysCtrl = sys;
+}
+
+-(void)setSystemTextLineSpacing:(float)height {
+    sysCtrlLineSpacing = height;
+}
+
+-(iSystemTextInput *)systemTextInput {
+    return sysCtrl;
+}
+
+- (CGFloat)layoutManager:(NSLayoutManager *)layoutManager
+        lineSpacingAfterGlyphAtIndex:(NSUInteger)glyphIndex
+        withProposedLineFragmentRect:(CGRect)rect {
+    return sysCtrlLineSpacing / get_MainWindow()->base.pixelRatio;
+}
+
 - (BOOL)textField:(UITextField *)textField shouldChangeCharactersInRange:(NSRange)range
 replacementString:(NSString *)string {
     iSystemTextInput *sysCtrl = [appState_ systemTextInput];
@@ -312,11 +329,6 @@ replacementString:(NSString *)string {
     notifyChange_SystemTextInput_(sysCtrl);
 }
 
-- (BOOL)scrollViewShouldScrollToTop:(UIScrollView *)scrollView {
-    postCommand_App("scroll.top smooth:1");
-    return NO;
-}
-
 @end
 
 /*----------------------------------------------------------------------------------------------*/
@@ -745,17 +757,17 @@ static CGRect convertToCGRect_(const iRect *rect, iBool expanded) {
     CGRect frame;
     // TODO: Convert coordinates properly!
     frame.origin.x = rect->pos.x / win->pixelRatio;
-    frame.origin.y = (rect->pos.y - gap_UI + 1) / win->pixelRatio;
+    frame.origin.y = (rect->pos.y - gap_UI * 0.875f) / win->pixelRatio;
     frame.size.width = rect->size.x / win->pixelRatio;
     frame.size.height = rect->size.y / win->pixelRatio;
     /* Some padding to account for insets. If we just zero out the insets, the insertion point
        may be clipped at the edges. */
+    const float inset = gap_UI / get_Window()->pixelRatio;
     if (expanded) {
-        const float inset = gap_UI / get_Window()->pixelRatio;
-        frame.origin.x -= inset + 1;
-        frame.origin.y -= inset + 1;
-        frame.size.width += 2 * inset + 2;
-        frame.size.height += inset + 1 + inset;
+        frame.origin.x -= 2 * inset;
+        frame.origin.y -= inset;
+        frame.size.width += 4 * inset;
+        frame.size.height += 2.5f * inset;
     }
     return frame;
 }
@@ -806,24 +818,31 @@ void init_SystemTextInput(iSystemTextInput *d, iRect rect, int flags) {
             [REF_d_view setTextAlignment:NSTextAlignmentRight];
         }
     }
-    UIColor *textColor = makeUIColor_(uiInputTextFocused_ColorId);
+    UIColor *textColor       = makeUIColor_(uiInputTextFocused_ColorId);
     UIColor *backgroundColor = makeUIColor_(uiInputBackgroundFocused_ColorId);
-    UIColor *tintColor = makeUIColor_(uiInputFrameHover_ColorId); /* use the accent color */ //uiInputCursor_ColorId);
+    UIColor *tintColor       = makeUIColor_(uiInputCursor_ColorId);
     [appState_ setSystemTextInput:d];
+    const float inset = gap_UI / get_Window()->pixelRatio;
     if (d->field) {
         UITextField *field = REF_d_field;
         [field setTextColor:textColor];
         [field setTintColor:tintColor];
+//        [field setBackgroundColor:[UIColor colorWithRed:1.0f green:0.0f blue:0.0f alpha:0.5f]];
         [field setDelegate:appState_];
         [field becomeFirstResponder];
     }
     else {
         UITextView *view = REF_d_view;
+        [[view layoutManager] setDelegate:appState_];
         [view setBackgroundColor:[UIColor colorWithWhite:1.0f alpha:0.0f]];
+//        [view setBackgroundColor:[UIColor colorWithRed:1.0f green:0.0f blue:0.0f alpha:0.5f]];
         [view setTextColor:textColor];
         [view setTintColor:tintColor];
         if (flags & extraPadding_SystemTextInputFlag) {
-            [view setContentInset:(UIEdgeInsets){ 0, 0, 3 * gap_UI / get_Window()->pixelRatio, 0}];
+            [view setContentInset:(UIEdgeInsets){ -inset * 0.125f, inset * 0.875f, 3 * inset, 0}];
+        }
+        else {
+            [view setContentInset:(UIEdgeInsets){ inset / 2, inset * 0.875f, -inset / 2, inset / 2 }];
         }
         [view setEditable:YES];
         [view setDelegate:appState_];
@@ -896,19 +915,20 @@ int preferredHeight_SystemTextInput(const iSystemTextInput *d) {
 void setFont_SystemTextInput(iSystemTextInput *d, int fontId) {
     float height = lineHeight_Text(fontId) / get_Window()->pixelRatio;
     UIFont *font;
-    //        for (NSString *name in [UIFont familyNames]) {
-    //            printf("family: %s\n", [name cStringUsingEncoding:NSUTF8StringEncoding]);
-    //        }
+//            for (NSString *name in [UIFont familyNames]) {
+//                printf("family: %s\n", [name cStringUsingEncoding:NSUTF8StringEncoding]);
+//            }
     if (fontId / maxVariants_Fonts * maxVariants_Fonts == monospace_FontId) {
 //        font = [UIFont monospacedSystemFontOfSize:0.8f * height weight:UIFontWeightRegular];
 //        for (NSString *name in [UIFont fontNamesForFamilyName:@"Iosevka Term"]) {
 //            printf("fontname: %s\n", [name cStringUsingEncoding:NSUTF8StringEncoding]);
 //        }
         font = [UIFont fontWithName:@"Iosevka-Term-Extended" size:height * 0.82f];
+        [appState_ setSystemTextLineSpacing:0.0f];
     }
     else {
-//        font = [UIFont systemFontOfSize:0.65f * height];
-        font = [UIFont fontWithName:@"SourceSans3-Regular" size:height * 0.7f];
+        font = [UIFont fontWithName:@"Roboto-Regular" size:height * 0.66f];
+        [appState_ setSystemTextLineSpacing:height * 0.66f];
     }
     if (d->field) {
         [REF_d_field setFont:font];
