@@ -38,6 +38,7 @@ struct Impl_SiteParams {
     int      dismissWarnings;
     iStringArray usedIdentities; /* fingerprints; latest ones at the end */
     iString  paletteSeed;
+    int      tlsSessionCache;
     /* TODO: style settings */
 };
 
@@ -47,6 +48,7 @@ void init_SiteParams(iSiteParams *d) {
     d->dismissWarnings = 0;
     init_StringArray(&d->usedIdentities);
     init_String(&d->paletteSeed);
+    d->tlsSessionCache = iTrue;
 }
 
 void deinit_SiteParams(iSiteParams *d) {
@@ -73,6 +75,7 @@ struct Impl_SiteSpec {
     iString     saveDir;
     iStringHash sites;
     iSiteParams *loadParams;
+    enum iImportMethod loadMethod;
 };
 
 static iSiteSpec   siteSpec_;
@@ -125,7 +128,10 @@ static void handleIniTable_SiteSpec_(void *context, const iString *table, iBool
     }
     else {
         iAssert(d->loadParams != NULL);
-        insert_StringHash(&d->sites, table, d->loadParams);
+        if (d->loadMethod == all_ImportMethod ||
+            (d->loadMethod == ifMissing_ImportMethod && !contains_StringHash(&d->sites, table))) {
+            insert_StringHash(&d->sites, table, d->loadParams);
+        }
         iReleasePtr(&d->loadParams);
     }
 }
@@ -155,62 +161,80 @@ static void handleIniKeyValue_SiteSpec_(void *context, const iString *table, con
     else if (!cmp_String(key, "paletteSeed") && value->type == string_TomlType) {
         set_String(&d->loadParams->paletteSeed, value->value.string);
     }
+    else if (!cmp_String(key, "tlsSessionCache") && value->type == boolean_TomlType) {
+        d->loadParams->tlsSessionCache = value->value.boolean;
+    }
 }
 
 static iBool load_SiteSpec_(iSiteSpec *d) {
-    iBool ok = iFalse;
+    iBool ok = iFalse;   
     iFile *f = new_File(collect_String(concatCStr_Path(&d->saveDir, fileName_SiteSpec_)));
     if (open_File(f, readOnly_FileMode | text_FileMode)) {
-        iTomlParser *toml = new_TomlParser();
-        setHandlers_TomlParser(toml, handleIniTable_SiteSpec_, handleIniKeyValue_SiteSpec_, d);
-        ok = parse_TomlParser(toml, collect_String(readString_File(f)));
-        delete_TomlParser(toml);
+        ok = deserialize_SiteSpec(stream_File(f), all_ImportMethod);
     }
     iRelease(f);
     iAssert(d->loadParams == NULL);
     return ok;
 }
 
+iBool deserialize_SiteSpec(iStream *ins, enum iImportMethod loadMethod) {
+    iSiteSpec *d = &siteSpec_;
+    d->loadMethod = loadMethod;
+    iTomlParser *toml = new_TomlParser();
+    setHandlers_TomlParser(toml, handleIniTable_SiteSpec_, handleIniKeyValue_SiteSpec_, d);
+    iBool ok = parse_TomlParser(toml, collect_String(readString_Stream(ins)));
+    delete_TomlParser(toml);
+    return ok;
+}
+
+void serialize_SiteSpec(iStream *out) {
+    iSiteSpec *d = &siteSpec_;
+    iString *buf = new_String();
+    iConstForEach(StringHash, i, &d->sites) {
+        iBeginCollect();
+        const iBlock *     key    = &i.value->keyBlock;
+        const iSiteParams *params = i.value->object;
+        clear_String(buf);
+        if (params->titanPort) {
+            appendFormat_String(buf, "titanPort = %u\n", params->titanPort);
+        }
+        if (!isEmpty_String(&params->titanIdentity)) {
+            appendFormat_String(
+                buf, "titanIdentity = \"%s\"\n", cstr_String(&params->titanIdentity));
+        }
+        if (params->dismissWarnings) {
+            appendFormat_String(buf, "dismissWarnings = 0x%x\n", params->dismissWarnings);
+        }
+        if (!isEmpty_StringArray(&params->usedIdentities)) {
+            appendFormat_String(
+                buf,
+                "usedIdentities = \"%s\"\n",
+                cstrCollect_String(joinCStr_StringArray(&params->usedIdentities, " ")));
+        }
+        if (!isEmpty_String(&params->paletteSeed)) {
+            appendCStr_String(buf, "paletteSeed = \"");
+            append_String(buf, collect_String(quote_String(&params->paletteSeed, iFalse)));
+            appendCStr_String(buf, "\"\n");
+        }
+        if (!params->tlsSessionCache) {
+            appendCStr_String(buf, "tlsSessionCache = false\n");
+        }
+        if (!isEmpty_String(buf)) {
+            writeData_Stream(out, "[", 1);
+            writeData_Stream(out, constData_Block(key), size_Block(key));
+            writeData_Stream(out, "]\n", 2);
+            appendCStr_String(buf, "\n");
+            write_Stream(out, utf8_String(buf));
+        }
+        iEndCollect();
+    }
+    delete_String(buf);    
+}
+
 static void save_SiteSpec_(iSiteSpec *d) {
     iFile *f = new_File(collect_String(concatCStr_Path(&d->saveDir, fileName_SiteSpec_)));
     if (open_File(f, writeOnly_FileMode | text_FileMode)) {
-        iString *buf = new_String();
-        iConstForEach(StringHash, i, &d->sites) {
-            iBeginCollect();
-            const iBlock *     key    = &i.value->keyBlock;
-            const iSiteParams *params = i.value->object;
-            clear_String(buf);
-            if (params->titanPort) {
-                appendFormat_String(buf, "titanPort = %u\n", params->titanPort);
-            }
-            if (!isEmpty_String(&params->titanIdentity)) {
-                appendFormat_String(
-                    buf, "titanIdentity = \"%s\"\n", cstr_String(&params->titanIdentity));
-            }
-            if (params->dismissWarnings) {
-                appendFormat_String(buf, "dismissWarnings = 0x%x\n", params->dismissWarnings);
-            }
-            if (!isEmpty_StringArray(&params->usedIdentities)) {
-                appendFormat_String(
-                    buf,
-                    "usedIdentities = \"%s\"\n",
-                    cstrCollect_String(joinCStr_StringArray(&params->usedIdentities, " ")));
-            }
-            if (!isEmpty_String(&params->paletteSeed)) {
-                appendCStr_String(buf, "paletteSeed = \"");
-                append_String(buf, collect_String(quote_String(&params->paletteSeed, iFalse)));
-                appendCStr_String(buf, "\"\n");
-            }
-            if (!isEmpty_String(buf)) {
-                writeData_File(f, "[", 1);
-                writeData_File(f, constData_Block(key), size_Block(key));
-                writeData_File(f, "]\n", 2);
-                appendCStr_String(buf, "\n");
-                write_File(f, utf8_String(buf));
-            }
-            iEndCollect();
-        }
-        delete_String(buf);
+        serialize_SiteSpec(stream_File(f));
     }
     iRelease(f);
 }
@@ -254,6 +278,12 @@ void setValue_SiteSpec(const iString *site, enum iSiteSpecKey key, int value) {
             params->dismissWarnings = value;
             needSave = iTrue;
             break;
+        case tlsSessionCache_SiteSpeckey:
+            if (value != params->tlsSessionCache) {
+                params->tlsSessionCache = value;
+                needSave = iTrue;
+            }
+            break;
         default:
             break;
     }
@@ -329,13 +359,21 @@ int value_SiteSpec(const iString *site, enum iSiteSpecKey key) {
     iSiteSpec *d = &siteSpec_;
     const iSiteParams *params = constValue_StringHash(&d->sites, collect_String(lower_String(site)));
     if (!params) {
-        return 0;
+        /* Default values. */
+        switch (key) {
+            case tlsSessionCache_SiteSpeckey:
+                return 1;
+            default:                
+                return 0;
+        }
     }
     switch (key) {
         case titanPort_SiteSpecKey:
             return params->titanPort;
         case dismissWarnings_SiteSpecKey:
             return params->dismissWarnings;
+        case tlsSessionCache_SiteSpeckey:
+            return params->tlsSessionCache;
         default:
             return 0;
     }    
