@@ -95,6 +95,7 @@ static iRect bounds_ScrollWidget_(const iScrollWidget *d) {
     iRect bounds = bounds_Widget(w);
     if (deviceType_App() == phone_AppDeviceType && isPortrait_App()) {
         /* Account for the hidable toolbar. */
+        /* TODO: use height of "bottombar" */
         int toolbarHeight = lineHeight_Text(uiLabelLarge_FontId) + 3 * gap_UI;
         int excess = bottom_Rect(bounds) - (bottom_Rect(safeRect_Root(w->root)) - toolbarHeight);
         if (excess > 0) {
@@ -110,7 +111,9 @@ static iRect thumbRect_ScrollWidget_(const iScrollWidget *d) {
     const int total = (int) size_Range(&d->range);
     if (total > 0) {
         const int tsize = thumbSize_ScrollWidget_(d);
-//        iAssert(tsize <= height_Rect(bounds));
+        if (tsize > height_Rect(bounds) * 0.95f) {
+            return rect;
+        }
         const int tpos =
             iClamp((float) d->thumb / (float) total, 0, 1) * (height_Rect(bounds) - tsize);
         rect.pos.y  = bounds.pos.y + tpos;
