@@ -438,12 +438,17 @@ iBool handleCommand_Translation(iTranslation *d, const char *cmd) {
             }
             setFlags_Widget(findChild_Widget(d->dlg, "xlt.from"), hidden_WidgetFlag, iTrue);
             setFlags_Widget(findChild_Widget(d->dlg, "xlt.to"),   hidden_WidgetFlag, iTrue);
-            if (!langs) langs = d->dlg;
+            if (!langs) {
+                langs = d->dlg;
+            }
             iLabelWidget *acceptButton = acceptButton_Translation_(d);
             updateTextCStr_LabelWidget(acceptButton, "00:00");
             setFlags_Widget(as_Widget(acceptButton), disabled_WidgetFlag, iTrue);
             iTranslationProgressWidget *prog = new_TranslationProgressWidget();
-            setPos_Widget(as_Widget(prog), langs->rect.pos);
+            if (isUsingPanelLayout_Mobile()) {
+                setPos_Widget(as_Widget(prog), init_I2(0, 22 * gap_UI)); /* TODO: No fixed offets... */
+            }
+//            setPos_Widget(as_Widget(prog), zero_I2()) ;// langs->rect.pos);
             setFixedSize_Widget(as_Widget(prog), init_I2(width_Rect(innerBounds_Widget(d->dlg)),
                                                          langs->rect.size.y));
             addChildFlags_Widget(d->dlg, iClob(prog), 0);
@@ -462,7 +467,7 @@ iBool handleCommand_Translation(iTranslation *d, const char *cmd) {
     if (equalWidget_Command(cmd, w, "translation.finished")) {
         if (!isFinished_Translation(d)) {
             if (processResult_Translation_(d)) {
-                setupSheetTransition_Mobile(d->dlg, iFalse);
+                setupSheetTransition_Mobile(d->dlg, dialogTransitionDir_Widget(d->dlg));
                 destroy_Widget(d->dlg);
                 d->dlg = NULL;
             }
@@ -479,7 +484,7 @@ iBool handleCommand_Translation(iTranslation *d, const char *cmd) {
             cancel_TlsRequest(d->request);
         }
         else {
-            setupSheetTransition_Mobile(d->dlg, iFalse);
+            setupSheetTransition_Mobile(d->dlg, dialogTransitionDir_Widget(d->dlg));
             destroy_Widget(d->dlg);
             d->dlg = NULL;
         }
